@@ -3,13 +3,15 @@ Main interface for backup service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.backup import BackupClient
+    from mypy_boto3_backup import BackupClient
 
     session = boto3.Session()
 
     client: BackupClient = boto3.client("backup")
     session_client: BackupClient = session.client("backup")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
