@@ -3,9 +3,11 @@ Main interface for backup service type definitions.
 
 Usage::
 
-    from mypy_boto3.backup.type_defs import BackupJobTypeDef
+    ```python
+    from mypy_boto3_backup.type_defs import BackupJobTypeDef
 
     data: BackupJobTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
